/*----------------------------------------------------------------------------
 * Nazwa:    GPIO_procedury.c	  
 * Funkcja: Plik procedur zwizanych z liniami portw	
 *          programu demonstracyjnego pytki KAMAMI
 *          dla ukadu ZXCT1086 
 * Version: V1.00
 *----------------------------------------------------------------------------
 * Plik zawiera:
 * procedury inicjacji portw I/O
 *
 * Copyright (c) 2012 ARIES. All rights reserved.
 *----------------------------------------------------------------------------*/
//#include "platform_config.h"
#include "stm32f10x.h"
#include "stm32f10x_conf.h"
#include "GPIO_procedury.h"
#include "stm32f10x_spi.h"


const uint32_t GPIO_LINE_CLK[LINEn]={LINE_DATA_CLK, LINE_CLK_CLK,
									 LINE_CS_CLK, LINE_RES_CLK};
const uint16_t GPIO_LINE_PIN[LINEn] ={LINE_DATA_PIN, LINE_CLK_PIN,
									 LINE_CS_PIN, LINE_RES_PIN};
GPIO_TypeDef* GPIO_LINE_PORT[LINEn] ={LINE_DATA_PORT, LINE_CLK_PORT,
									 LINE_CS_PORT, LINE_RES_PORT};

GPIO_InitTypeDef GPIO_InitStructure;

//--------------------------------
//procedury inicjacji linii portw
void GPIO_Inicjacja(void)
{
  /* Configure all unused GPIO port pins in Analog Input mode (floating input
     trigger OFF), this will reduce the power consumption and increase the device
     immunity against EMI/EMC *************************************************/
  //RCC_APB2PeriphClockCmd(RCC_APB2Periph_GPIOA | RCC_APB2Periph_GPIOB , ENABLE);

  GPIO_InitStructure.GPIO_Pin = GPIO_Pin_All;
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_AIN;
  GPIO_Init(GPIOA, &GPIO_InitStructure);
  GPIO_Init(GPIOB, &GPIO_InitStructure);

  RCC_APB2PeriphClockCmd(RCC_APB2Periph_GPIOA | RCC_APB2Periph_GPIOB |
                         RCC_APB2Periph_GPIOC | RCC_APB2Periph_GPIOD |
                         RCC_APB2Periph_GPIOE, DISABLE);  
  //inicjacja portw sterujcych liniami wywietlacza LCD KAmodTFT2
  GPIO_LINEInit(LINE_DATA, GPIO_Mode_Out_PP);
  GPIO_LINEInit(LINE_CLK, GPIO_Mode_Out_PP);
  GPIO_LINEInit(LINE_CS, GPIO_Mode_Out_PP);
  GPIO_LINEInit(LINE_RES, GPIO_Mode_Out_PP);
}
//-----------------------------------------
//procedura inicjacji linii sterujcych I/O
void GPIO_LINEInit(Line_TypeDef Line, GPIOMode_TypeDef Line_mode)
{
   GPIO_InitTypeDef  GPIO_InitStructure;
   
   /* Enable the GPIO_LINE Clock */
   RCC_APB2PeriphClockCmd(GPIO_LINE_CLK[Line], ENABLE);

   /* Configure the GPIO_LINE pin */
   GPIO_InitStructure.GPIO_Pin = GPIO_LINE_PIN[Line];
   GPIO_InitStructure.GPIO_Mode = Line_mode; 
   GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
 
   GPIO_Init(GPIO_LINE_PORT[Line], &GPIO_InitStructure);	

}
//------------------------------------------------------------
//procedura ustawienia stanu wysokiego na linii sterujcej I/O
void GPIO_LINEHigh(Line_TypeDef Line)
{
	GPIO_LINE_PORT[Line]->BSRR = GPIO_LINE_PIN[Line];
}
//-----------------------------------------------------------
//procedura ustawienia stanu niskiego na linii sterujcej I/O
void GPIO_LINELow(Line_TypeDef Line)
{
	GPIO_LINE_PORT[Line]->BRR = GPIO_LINE_PIN[Line];
}
//--------------------------------------------
//procedura odczytu stanu linii sterujcej I/O
uint32_t GPIO_LINEStanLinii(Line_TypeDef Line)
{
  	return GPIO_ReadInputDataBit(GPIO_LINE_PORT[Line], GPIO_LINE_PIN[Line]);
}
//-------------------------------------------
//inicjacja SPI
void SPI_Configuration(void)
{
  	SPI_InitTypeDef  SPI_InitStructure;
  	GPIO_InitTypeDef GPIO_InitStructure;

  	// Enable SPI1 and GPIO clocks 
  	RCC_APB2PeriphClockCmd(RCC_APB2Periph_SPI1 | RCC_APB2Periph_GPIOA, ENABLE);

  	// Configure SPI1 pins: SCK, MISO and MOSI 
  	GPIO_InitStructure.GPIO_Pin = GPIO_Pin_5 | GPIO_Pin_6 | GPIO_Pin_7;
  	GPIO_InitStructure.GPIO_Mode = GPIO_Mode_AF_PP;
  	GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
  	GPIO_Init(GPIOA, &GPIO_InitStructure);
/*
  	// Configure I/O for Flash Chip select 
  	GPIO_InitStructure.GPIO_Pin = GPIO_Pin_CS;
  	GPIO_InitStructure.GPIO_Mode = GPIO_Mode_Out_PP;
  	GPIO_Init(GPIO_CS, &GPIO_InitStructure);
*/
  	// SPI1 configuration 
  	SPI_InitStructure.SPI_Direction = SPI_Direction_2Lines_FullDuplex;
  	SPI_InitStructure.SPI_Mode = SPI_Mode_Master;
  	SPI_InitStructure.SPI_DataSize = SPI_DataSize_8b;
  	SPI_InitStructure.SPI_CPOL = SPI_CPOL_High;
  	SPI_InitStructure.SPI_CPHA = SPI_CPHA_2Edge;
  	SPI_InitStructure.SPI_NSS = SPI_NSS_Soft;
  	SPI_InitStructure.SPI_BaudRatePrescaler = SPI_BaudRatePrescaler_256;
  	SPI_InitStructure.SPI_FirstBit = SPI_FirstBit_MSB;
  	SPI_InitStructure.SPI_CRCPolynomial = 7;
  	SPI_Init(SPI1, &SPI_InitStructure);

  	// Enable SPI1  
  	SPI_Cmd(SPI1, ENABLE);
}



